@@ -1,6 +1,6 @@
 package Koha::Contrib::Tamil::RecordWriter::File::Iso2709;
 {
-  $Koha::Contrib::Tamil::RecordWriter::File::Iso2709::VERSION = '0.011';
+  $Koha::Contrib::Tamil::RecordWriter::File::Iso2709::VERSION = '0.012';
 }
 #ABSTRACT: ISO2709 MARC records writer
 use Moose;
@@ -24,25 +24,14 @@ sub write {
     my ( $self, $record ) = @_;
 
     $self->SUPER::write();
-    my $fh = $self->fh;
 
-    if ( ref($record) eq 'MARC::Record' ) {
-        print $fh $record->as_usmarc(); 
-    }
-    else {
-        my $rec = MARC::Record::new_from_xml( $record, "utf8" );
-        my $leader = $rec->leader;
-        if ( length($leader) > 24 ) {
-            $rec->leader( substr($leader, 0, 24) );
-        }
-        print $fh $rec->as_usmarc;
-    }
+    my $fh = $self->fh;
+    print $fh $record->as_usmarc(); 
 }
 
 __PACKAGE__->meta->make_immutable;
 
-1;
-
+1
 
 __END__
 =pod
@@ -55,7 +44,7 @@ Koha::Contrib::Tamil::RecordWriter::File::Iso2709 - ISO2709 MARC records writer
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 AUTHOR
 
