@@ -1,6 +1,6 @@
 package Koha::Contrib::Tamil::Sitemaper;
 {
-  $Koha::Contrib::Tamil::Sitemaper::VERSION = '0.011';
+  $Koha::Contrib::Tamil::Sitemaper::VERSION = '0.012';
 }
 # ABSTRACT: Class building Sitemap files for a Koha DB
 
@@ -8,7 +8,6 @@ use Moose;
 
 extends 'Koha::Contrib::Tamil::FileProcess';
 
-use Carp;
 use Koha::Contrib::Tamil::Koha;
 use Koha::Contrib::Tamil::Sitemaper::Writer;
 use Locale::TextDomain 'Koha-Contrib-Tamil';
@@ -26,60 +25,50 @@ has verbose => ( is => 'rw', isa => 'Bool', default => 0 );
 
 has sth => ( is => 'rw' );
 
-has writer => (
-    is => 'rw',
-    isa => 'Koha::Contrib::Tamil::Sitemaper::Writer',
-);
+has writer => ( is => 'rw', isa => 'Koha::Contrib::Tamil::Sitemaper::Writer' );
 
 
 
-sub BUILD {
-    my $self = shift;
-}
-
-
 before 'run' => sub {
     my $self = shift;
 
     $self->koha( Koha::Contrib::Tamil::Koha->new() ) unless $self->koha;
     $self->writer(
-        Koha::Contrib::Tamil::Sitemaper::Writer->new(
-            url => $self->url ) );
+        Koha::Contrib::Tamil::Sitemaper::Writer->new( url => $self->url ) );
 
     my $sth = $self->koha->dbh->prepare(
-         "SELECT biblionumber, timestamp FROM biblio"  );
+         "SELECT biblionumber, timestamp FROM biblio" );
     $sth->execute();
     $self->sth( $sth );
 };
 
 
-sub process {
+override 'process' => sub {
     my $self = shift;
 
     my ($biblionumber, $timestamp) = $self->sth->fetchrow;
-    return 0 unless $biblionumber;
+    return unless $biblionumber;
 
-    $self->SUPER::process();
     $self->writer->write($biblionumber, $timestamp);
-}
+    return super();
+};
 
 
 before 'end_process' => sub { shift->writer->end(); };
 
 
-sub start_message {
+override 'start_message' => sub {
     print __"Creation of Sitemap files\n";
-}
+};
 
 
-sub end_message {
+override 'end_message' => sub {
     my $self = shift;
-
     print __x("Number of biblio records processed: {biblios}\n" .
               "Number of Sitemap files:            {files}\n",
               biblios => $self->count,
               files => $self->writer->count );
-}
+};
 
 
 no Moose;
@@ -97,7 +86,7 @@ Koha::Contrib::Tamil::Sitemaper - Class building Sitemap files for a Koha DB
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =HEAD1 SYNOPSIS
 
